@@ -4,6 +4,7 @@ import logging
 
 import requests
 from mobio.libs.Singleton import Singleton
+from mobio.sdks.admin import MobioAdminSDK
 
 from .config import MobioEnvironment
 
@@ -33,23 +34,16 @@ class MerchantConfig:
         return self.configs[merchant_id]
 
     def __request_get_merchant_auth(self, merchant_id):
-        adm_url = MobioEnvironment.ADM_CONFIG.format(host=self.admin_host, merchant_id=merchant_id)
-        headers = {'Authorization': MobioEnvironment.MOBIO_TOKEN}
-        logger.debug('::get_merchant_auth: adm_url = %s' % adm_url)
-        response = requests.get(adm_url, headers=headers)
-        response.raise_for_status()
-
-        result = response.json()
-        logger.debug('::get_merchant_auth: result = %s' % result)
+        merchant_config_host = MobioAdminSDK().request_get_merchant_config_host(
+            merchant_id,
+            key=None,
+        )
 
         # media_host = result['data']['media_host']
         # if media_host.endswith('/'):
         #     media_host = media_host[:-1]
         return {
-            MerchantConfig.JWT_ALGORITHM: result['data']['jwt_algorithm'],
-            MerchantConfig.JWT_SECRET_KEY: result['data']['jwt_secret_key'],
-            MerchantConfig.BASIC_TOKEN: 'Basic ' + result['data']['p_t'],
-            MerchantConfig.MEDIA_HOST: result['data']['media_host']
+            "public_host": merchant_config_host["public-host"],
         }
 
     def set_current_merchant(self, merchant_id):
